import requests
import json

class KoboData:
    def __init__(self,account_domain, data_uuid, token):
        self.account_domain = account_domain
        self.data_uuid = data_uuid
        self.token     = token
    
    @property
    def kobo_data(self):
        url = 'https://{}/api/v2/assets/{}/data/?format=json'.format(self.account_domain, self.data_uuid)
        headers = {'Authorization': 'Token {}'.format(self.token)}
        r = requests.get(url, headers=headers)
        if r.status_code == 200:
            return json.loads(r.content)
        return {"error":"Incorrect Authy Details"}

    
    
    @property
    def counts(self):
        data = KoboData(self.account_domain, self.data_uuid, self.token).kobo_data
        return data['count']

    @property
    def get_data(self):
        data = KoboData(self.account_domain, self.data_uuid, self.token).kobo_data
        return data['results']

__doc__ = """

For Documentation check out https://github.com/kalokola/kobodata/blob/main/README.md
"""


import setuptools

with open("README.md", "r") as fh:
	long_description = fh.read()

setuptools.setup(
	description="Python Tool for accessing online data from KOBO TOOLBOX.",
	name="kobodata",
	version="0.0.9",
	author = "Brightius Kalokola",
	author_email = "brightiuskalokola@gmail.com",
	long_description = long_description,
	long_description_content_type="text/markdown",
	url = "",
	packages=setuptools.find_packages(),
	summary = None,
	home_page = None,
	install_requires=["requests"],
	license="MIT",
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
)